/*
 * Copyright (c) 2003, 2004 Henri Sivonen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package fi.iki.hsivonen.template;
import java.io.IOException;

/**
 * An <code>Item</code> represents a data item such as an image,  
 * a zip file or an XHTML document. However, the actual data of the item is not 
 * available through this interface but through the subinterfaces is of this 
 * interface. This interface provides access to commonly used metadata.
 *
 * @version $Id: Item.java,v 1.13 2004/08/28 16:20:07 hsivonen Exp $
 * @author  hsivonen
 */
public interface Item {

    /**
     * Returns the title of the item or <code>null</code> if the item has no 
     * title. For XHTML documents this must be the parsed text content 
     * (no escaping) of the <code>title</code> element.
     *
     * @return the title of the item
     *
     * @throws IOException if an I/O error occurs
     * @throws DataSourceException if any other difficulty is encountered
     */
    public String getTitle() throws DataSourceException, IOException;

    /** 
     * Returns the modification date of this item or <code>null</code> if the 
     * creation date is unknown. 
     *
     * @return the modification date of this item or <code>null</code> if unknown
     *
     * @throws IOException if an I/O error occurs
     * @throws DataSourceException if any other difficulty is encountered
     */
    public java.util.Date getDateModified()
        throws DataSourceException, IOException;

    /**
     * The URL that primarily addresses this item. For example, if this item 
     * is an article, GETting the URL would return a page with this article 
     * as the main content (even if the page also contained snippets of content 
     * from other items). If this item is not directly addressable, this 
     * method returns <code>null</code>. 
     *
     * @return the URL for addressing this item or <code>null</code> if
     *         unaddressable
     *
     * @throws IOException if an I/O error occurs
     * @throws DataSourceException if any other difficulty is encountered
     */
    public java.net.URL getURL() throws DataSourceException, IOException;

}
